@@ -37,10 +37,10 @@
 #include <ctype.h>
 #include <time.h>
 
-#include "maptemplate.h"
-#include "maptile.h"
+#include "../maptemplate.h"
+#include "../maptile.h"
 
-#include "cgiutil.h"
+#include "../cgiutil.h"
 
 /*
 ** Defines
@@ -51,7 +51,11 @@
 /*
 ** Macros
 */
-#define TEMPLATE_TYPE(s)  (((strncmp("http://", s, 7) == 0) || (strncmp("https://", s, 8) == 0) || (strncmp("ftp://", s, 6)) == 0)  ? MS_URL : MS_FILE)
+#define TEMPLATE_TYPE(s)                                                       \
+  (((strncmp("http://", s, 7) == 0) || (strncmp("https://", s, 8) == 0) ||     \
+    (strncmp("ftp://", s, 6)) == 0)                                            \
+       ? MS_URL                                                                \
+       : MS_FILE)
 
 MS_DLL_EXPORT void msCGIWriteError(mapservObj *mapserv);
 MS_DLL_EXPORT mapObj *msCGILoadMap(mapservObj *mapserv, configObj *context);
